@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, date
 from typing import Optional
 from sqlmodel import Field, Relationship, SQLModel
 
@@ -9,6 +9,7 @@ class TodoBase(SQLModel):
     status: str = Field(default='todo')
     tags: str | None
     due_date: datetime | None
+    date_added: datetime | None
     project_id: Optional[int] = Field(default=None, foreign_key="project.id")
 
 
@@ -23,11 +24,12 @@ class TodoUpdate(SQLModel):
     status: Optional[str] = None
     tags: list[str] | None = None
     due_date: datetime | None = None
+    date_added: datetime | None = None
     project_id: Optional[int] = None
 
 
 class TodoCreate(TodoBase):
-    pass
+    date_added: datetime | None = datetime.now()
 
 
 class TodoRead(TodoBase):
@@ -60,4 +62,4 @@ class TodoReadWithProject(TodoRead):
 
 
 class ProjectReadWithTodos(ProjectRead):
-    todos: list[TodoRead] = []
\ No newline at end of file
+    todos: list[TodoRead] = []
